new;
library pgraph;

data = loadd("cac-dj");

CAC40 = data[.,2];        /* CAC 40 */

y = ln(CAC40);
r = packr(y - lag1(y));   /* (log)returns of the CAC40 index */

muGaussian = meanc(r);    /* estimated parameters for the Gaussian distribution */
sigmaGaussian = stdc(r);

nu = 3;   /* df of the Student distribution */

muStudent = meanc(r);    /* estimated parameters for the Student distribution */
sigmaStudent = stdc(r)/sqrt(nu/(nu-2));

N = 1~22~262~262*10;

x = seqa(-0.20,0.50/1000,1001);
x1 = (x - muGaussian) ./ sigmaGaussian;
g1 = N .* cdfn(x1)^(N-1) .* pdfn(x1) ./ sigmaGaussian;

x2 = (x - muStudent) ./ sigmaStudent;
g2 = N .* cdft(x2,nu)^(N-1) .* pdft(x2,nu) ./ sigmaStudent;

graphset;
  begwind;
  window(2,2,0);

  _pframe = 0; _pnum = 2; _pltype = 6|3;
  _pnumht = 0.20; _ptitlht = 0.25; _paxht = 0.20;
  xlabel("return of the CAC40 index");
  ylabel("pdf of G]N[");

  setwind(1);
    title("One trading day");
    xtics(-0.05,0.10,0.05,2);
    ytics(0,50,10,2);
    xy(x,g1[.,1]~g2[.,1]);

  setwind(2);
    title("One month of trading");
    xtics(0,0.15,0.05,2);
    ytics(0,60,20,2);
    xy(x,g1[.,2]~g2[.,2]);

  setwind(3);
    title("One year of trading");
    xtics(0,0.20,0.05,2);
    ytics(0,80,20,2);
    xy(x,g1[.,3]~g2[.,3]);

  setwind(4);
    title("Ten years of trading");
    xtics(0,0.25,0.05,2);
    ytics(0,90,30,2);
    _plegstr = "Gaussian\000Student";
    _plegctl = {2 6 5 3};
    xy(x,g1[.,4]~g2[.,4]);

    graphprt("-c=1 -cf=cac1.ps");

  endwind;

proc cdft(x,nu);
  retp( 1 - cdftc(x,nu) );
endp;

proc pdft(x,nu);
  retp( gamma((nu+1)./2) ./ gamma(nu./2) ./ sqrt(nu.*pi) .*
       (1+x^2./nu)^(-(nu+1)./2) );
endp;
